==> java-client-0.518.0-sources.jar: io/fluxcapacitor/javaclient/tracking/handling/validation/ValidatingInterceptor.java <==
/*
 * Copyright (c) 2016-2020 Flux Capacitor.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *     http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package io.fluxcapacitor.javaclient.tracking.handling.validation;

import io.fluxcapacitor.common.MessageType;
import io.fluxcapacitor.common.handling.Handler;
import io.fluxcapacitor.javaclient.common.Message;
import io.fluxcapacitor.javaclient.common.serialization.DeserializingMessage;
import io.fluxcapacitor.javaclient.publishing.DispatchInterceptor;
import io.fluxcapacitor.javaclient.tracking.handling.HandlerInterceptor;
import lombok.AllArgsConstructor;

import java.util.function.Function;

import static io.fluxcapacitor.javaclient.tracking.handling.validation.ValidationUtils.defaultValidator;

@AllArgsConstructor
public class ValidatingInterceptor implements HandlerInterceptor, DispatchInterceptor {
    private final Validator validator;

    public ValidatingInterceptor() {
        this.validator = defaultValidator;
    }

    @Override
    public Message interceptDispatch(Message message, MessageType messageType) {
        ValidationUtils.assertValid(message.getPayload(), validator);
        return message;
    }

    @Override
    public Function<DeserializingMessage, Object> interceptHandling(Function<DeserializingMessage, Object> function,
                                                                    Handler<DeserializingMessage> handler, String consumer) {
        return m -> {
            ValidationUtils.assertValid(m.getPayload(), validator);
            return function.apply(m);
        };
    }
}

==> java-client-0.688.0-sources.jar: io/fluxcapacitor/javaclient/tracking/handling/validation/ValidatingInterceptor.java <==
/*
 * Copyright (c) 2016-2020 Flux Capacitor.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *     http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package io.fluxcapacitor.javaclient.tracking.handling.validation;

import io.fluxcapacitor.common.MessageType;
import io.fluxcapacitor.common.handling.HandlerInvoker;
import io.fluxcapacitor.javaclient.common.Message;
import io.fluxcapacitor.javaclient.common.serialization.DeserializingMessage;
import io.fluxcapacitor.javaclient.publishing.DispatchInterceptor;
import io.fluxcapacitor.javaclient.tracking.handling.HandlerInterceptor;
import lombok.AllArgsConstructor;

import java.util.function.Function;

import static io.fluxcapacitor.javaclient.tracking.handling.validation.ValidationUtils.defaultValidator;

@AllArgsConstructor
public class ValidatingInterceptor implements HandlerInterceptor, DispatchInterceptor {
    private final Validator validator;

    public ValidatingInterceptor() {
        this.validator = defaultValidator;
    }

    @Override
    public Message interceptDispatch(Message message, MessageType messageType) {
        ValidationUtils.assertValid(message.getPayload(), validator);
        return message;
    }

    @Override
    public Function<DeserializingMessage, Object> interceptHandling(Function<DeserializingMessage, Object> function,
                                                                    HandlerInvoker invoker, String consumer) {
        return m -> {
            ValidationUtils.assertValid(m.getPayload(), validator);
            return function.apply(m);
        };
    }
}
